==> calibre_3.10.0%2Bdfsg.orig.tar.xz: calibre-3.10.0/README.md <==
calibre
=========

<img align="left" src="resources/images/lt.png?raw=true"/>

calibre is an e-book manager. It can view, convert, edit and catalog e-books 
in all of the major e-book formats. It can also talk to e-book reader 
devices. It can go out to the internet and fetch metadata for your books. 
It can download newspapers and convert them into e-books for convenient 
reading. It is cross platform, running on Linux, Windows and OS X.

For more information, see the [calibre About page](https://calibre-ebook.com/about)

[![Build Status](https://api.travis-ci.org/kovidgoyal/calibre.svg)](https://travis-ci.org/kovidgoyal/calibre)
[![Build status](https://ci.appveyor.com/api/projects/status/v3nkfq0t3pse8lep?svg=true&passingText=windows%20OK&failingText=windows%20KO)](https://ci.appveyor.com/project/kovidgoyal/calibre)

Screenshots
-------------
[Screenshots page](https://calibre-ebook.com/demo)

Usage
-------
See the [User Manual](https://manual.calibre-ebook.com)

Development
-------------
[Setting up a development environment for calibre](https://manual.calibre-ebook.com/develop.html)


A [tarball of the source code](https://calibre-ebook.com/dist/src) for the 
current calibre release.

Bugs
------

Bug reports and feature requests should be made in the calibre bug tracker at [launchpad](https://bugs.launchpad.net/calibre).
GitHub is only used for code hosting and pull requests.

Support calibre
----------------

calibre is a result of the efforts of many volunteers from all over the world.
If you find it useful, please consider contributing to support its development.
[Donate to support calibre development](https://calibre-ebook.com/donate).

==> calibre_3.48.0%2Bdfsg.orig.tar.xz: calibre-3.48.0/README.md <==
# calibre

<img align="left" src="resources/images/lt.png?raw=true" height="200" width="200"/>

calibre is an e-book manager. It can view, convert, edit and catalog e-books 
in all of the major e-book formats. It can also talk to e-book reader 
devices. It can go out to the internet and fetch metadata for your books. 
It can download newspapers and convert them into e-books for convenient 
reading. It is cross platform, running on Linux, Windows and macOS.

For more information, see the [calibre About page](https://calibre-ebook.com/about)

[![Build Status](https://api.travis-ci.org/kovidgoyal/calibre.svg?branch=master)](https://travis-ci.org/kovidgoyal/calibre)
[![Build status](https://ci.appveyor.com/api/projects/status/github/kovidgoyal/calibre?svg=true&branch=master)](https://ci.appveyor.com/project/kovidgoyal/calibre)  

## Screenshots  

[Screenshots page](https://calibre-ebook.com/demo)

## Usage

See the [User Manual](https://manual.calibre-ebook.com)

## Development

[Setting up a development environment for calibre](https://manual.calibre-ebook.com/develop.html)

A [tarball of the source code](https://calibre-ebook.com/dist/src) for the 
current calibre release.

## Bugs

Bug reports and feature requests should be made in the calibre bug tracker at [launchpad](https://bugs.launchpad.net/calibre).
GitHub is only used for code hosting and pull requests.

## Support calibre

calibre is a result of the efforts of many volunteers from all over the world.
If you find it useful, please consider contributing to support its development.
[Donate to support calibre development](https://calibre-ebook.com/donate).
